==> keepassx_0.2.2.orig.tar.gz: keepassx-0.2.2/src/import/Import_KWalletXml.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Tarek Saidi                                     *
 *   mail@tarek-saidi.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _IMPORT_KWALLET_H_
#define _IMPORT_KWALLET_H_
#include <qstring.h>
#include "PwManager.h"

class Import_KWalletXml{
public:
  bool importFile(QString FileName,Database* db,QString& err);
private:

};

#endif

==> keepassx-0.4.3.tar.gz: keepassx-0.4.3/src/import/Import_KWalletXml.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Tarek Saidi                                     *
 *   tarek.saidi@arcor.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *

 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
#ifndef _IMPORT_KWALLET_H_
#define _IMPORT_KWALLET_H_

#include "Import.h"

class Import_KWalletXml:public ImporterBase, public IImport{
	Q_OBJECT
	
	public:
		virtual bool importDatabase(QWidget* GuiParent, IDatabase* Database);
		virtual QString identifier(){return "KWalletXml";}
		virtual QString title(){return "KWallet XML File (*.xml)";}
};

#endif
